@@ -31,6 +31,8 @@ class MainWindow(QtGui.QMainWindow):
         if os.path.isfile("/opt/quizzynator/main.py"):
             self.ui=loadUi("/opt/quizzynator/quiz.ui")
             self.ui.show()
+###########################################################################################################################
+            
             self.ui.showFullScreen()
             self.ui.setAttribute(Qt.WA_Maemo5PortraitOrientation, True)            
             try:
@@ -80,6 +82,7 @@ class MainWindow(QtGui.QMainWindow):
         self.ui.beenden.clicked.connect(self.exit_nosave)
         self.ui.close.clicked.connect(self.exit_save)
         self.ui.minimize.clicked.connect(self.minimizefunc)
+        self.ui.minimize_2.clicked.connect(self.minimizefunc)
         self.ui.neuesspiel.clicked.connect(self.neuesspiel)
         self.ui.beginnen.clicked.connect(self.spielstarten)
         self.ui.zurueck.clicked.connect(self.settings)
@@ -102,6 +105,7 @@ class MainWindow(QtGui.QMainWindow):
         self.ui.craveofrage.clicked.connect(self.send_email)
         self.ui.spielladen.clicked.connect(self.spielladen)
         self.ui.highscores.clicked.connect(self.highscores)
+        self.ui.del_score.clicked.connect(self.del_highscores)
         self.ui.start_ng.clicked.connect(self.neuesspiel)
         self.ui.about.clicked.connect(self.aboutquiz)
         self.ui.linktohomepage.clicked.connect(self.craveobrowser)
@@ -183,9 +187,7 @@ class MainWindow(QtGui.QMainWindow):
             self.niederlagencounter=0
             self.score=0
             self.anzahlfragen=0
-            self.rangcounter=0
-    
-    
+            self.rangcounter=0    
     def choose_frage(self):
 #Rankingabfragen
         self.anzahlfragen+=1   
@@ -270,9 +272,7 @@ class MainWindow(QtGui.QMainWindow):
             self.ui.nextquest.show()
             self.soundfalsch()   
                 
-        self.status_check()
-                 
-             
+        self.status_check()                     
     def antwort_2(self):
         antwort=self.ui.antwort_2.text()
         antwort="%s" % unicode(antwort)
@@ -299,8 +299,7 @@ class MainWindow(QtGui.QMainWindow):
             self.ui.antwort_3.hide()
             self.ui.antwort_4.hide() 
             self.soundfalsch() 
-        self.status_check()                     
-                   
+        self.status_check()                                  
     def antwort_3(self):
         antwort=self.ui.antwort_3.text()
         antwort="%s" % unicode(antwort)
@@ -359,7 +358,6 @@ class MainWindow(QtGui.QMainWindow):
         self.status_check()
     def settings(self):
         self.ui.stackedWidget.setCurrentIndex(1)  
-        
     def load_user(self):
         userdata={}
         fobj=open(self.savegame,"r")
@@ -369,7 +367,8 @@ class MainWindow(QtGui.QMainWindow):
         fobj.close    
         self.spielername=userdata["Spielername"]
         self.niederlagencounter=userdata["Niederlagen"]
-        self.score=userdata["Score"]        
+        self.score=userdata["Score"]    
+        self.limit=int(userdata["Limit"])    
         self.niederlagencounter=int(self.niederlagencounter)
         self.score=int(self.score)
         self.ui.playername.setText(self.spielername)
@@ -379,8 +378,6 @@ class MainWindow(QtGui.QMainWindow):
         self.ui.antwort_3.hide()
         self.ui.antwort_4.hide()
         self.ui.textfrage.setText(u"Spielstand erfolgreich geladen.Sie können nun fortfahren.")
-                            
-        
     def save_settings(self):
 #Funktionsname outdated.Hier wird der Spielstand gespeichert.Derzeit klappt das nur, wenn man die Applikation im Fullscreenmode laufen lässt und auf Beenden klickt
 #Ein klick auf X zeigt keine wirkung
@@ -388,11 +385,13 @@ class MainWindow(QtGui.QMainWindow):
                
         userdata={"Spielername":str(self.spielername),
                   "Score":str(self.score),
-                  "Niederlagen":str(self.niederlagencounter)}
+                  "Niederlagen":str(self.niederlagencounter),
+                  "Limit":str(self.limit)}
                 
         for data in userdata:
             default.write(data+" " + userdata[data]+"\n")
         default.close()
+        
     def save_highscore(self):    
 #Highscore speichern
         if os.path.isfile(self.highscoredatenbank):
@@ -410,7 +409,12 @@ class MainWindow(QtGui.QMainWindow):
         fobj.write(self.scores)
         fobj.close()        
                 
-           
+    def del_highscores(self):
+        fobj=open(self.highscoredatenbank,"w")
+        fobj.write("")
+        fobj.close()
+        self.ui.highscoreanzeige.setText("")
+                
        
     def highscores(self):
 #Highscore anzeigen
@@ -469,16 +473,12 @@ class MainWindow(QtGui.QMainWindow):
             self.ui.minimize.show()
             self.ui.close.show()
             self.ui.settings.show()
-            
-            
     def format(self):
 #Bildformat ändern
         if self.ui.hochformat.isChecked():
             self.ui.setAttribute(Qt.WA_Maemo5PortraitOrientation, True)
         if self.ui.querformat.isChecked():
             self.ui.setAttribute(Qt.WA_Maemo5PortraitOrientation, False) 
-             
-        
     def craveobrowser(self):
         webbrowser.open("http://www.craveo.de")
         
@@ -497,7 +497,6 @@ class MainWindow(QtGui.QMainWindow):
         self.ui.label_12.show()
         self.ui.label_13.show()
         self.ui.setAttribute(Qt.WA_Maemo5PortraitOrientation, False)
-        
     def send_email(self):       
         self.emailfrage=self.ui.emailquestion.text()
         self.emailfrage=self.emailfrage.toLatin1()   
